Leave-one-out cross-validation via Rasmussen & Williams (2006) shortcut
Source:R/loo_cv.R
loo_cv.RdComputes closed-form LOO-CV predictions at NOAA sites using the block version of Rasmussen & Williams (2006) eq. 5.12. For site k with observation block B_k, the LOO predictive mean and covariance are computed from the precision matrix without refitting.
Usage
loo_cv(model, ...)
# S3 method for class 'evfuse_model'
loo_cv(model, loo_source = NULL, ...)
# S3 method for class 'evfuse_naive_model'
loo_cv(model, ...)